%{!?tcl_version: %global tcl_version %(echo 'puts $tcl_version' | tclsh)}
%{!?tcl_sitearch: %global tcl_sitearch %{_libdir}/tcl%{tcl_version}}

Name:          xapian-bindings
Version:       1.4.14
Release:       1%{?dist}
Summary:       Bindings for the Xapian Probabilistic Information Retrieval Library

License:       GPLv2+
URL:           http://www.xapian.org/
Source0:       http://www.oligarchy.co.uk/xapian/%{version}/%{name}-%{version}.tar.xz
# BZ#1800264
# Hint for a fix: https://github.com/swig/swig/issues/1689
#Patch0:        xapian-bindings-01-swig-ruby-27.patch


# Only build py3 support on Fedora and EPEL
%if 0%{?rhel} <= 6
%define with_py3 0
%else
%define with_py3 1
%endif

BuildRequires: gcc gcc-c++
BuildRequires: libuuid-devel
%if 0%{?with_py3}
BuildRequires: python3-devel python3-setuptools python3-sphinx
%endif
BuildRequires: ruby ruby-devel rubygems rubygem-rdoc rubygem-json
BuildRequires: tcl-devel
BuildRequires: xapian-core-devel
BuildRequires: zlib-devel

# Filter private-shared-object-provides
%{?filter_setup}

%description
Xapian is an Open Source Probabilistic Information Retrieval Library. It
offers a highly adaptable toolkit that allows developers to easily add advanced
indexing and search facilities to applications. This package provides the
files needed for scripts which use Xapian.

%if 0%{?with_py3}
%package -n python3-xapian
Summary:       Python 3 bindings for Xapian
Requires:      %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-xapian}

%description -n python3-xapian
Xapian is an Open Source Probabilistic Information Retrieval framework. It
offers a highly adaptable toolkit that allows developers to easily add advanced
indexing and search facilities to applications. This package provides the
bindings needed for developing Python3 scripts which use Xapian.
%endif

%package ruby
Summary:       Files needed for developing Ruby scripts which use Xapian
Requires:      %{name} = %{version}-%{release}
Requires:      ruby-libs

%description ruby
Xapian is an Open Source Probabilistic Information Retrieval framework. It
offers a highly adaptable toolkit that allows developers to easily add advanced
indexing and search facilities to applications. This package provides the
files needed for developing Ruby scripts which use Xapian

%package -n tcl-xapian
Summary:       Files needed for developing TCL scripts which use Xapian
Requires:      %{name} = %{version}-%{release}

%description -n tcl-xapian
Xapian is an Open Source Probabilistic Information Retrieval framework. It
offers a highly adaptable toolkit that allows developers to easily add advanced
indexing and search facilities to applications. This package provides the
files needed for developing TCL scripts which use Xapian

%prep
%autosetup -p1

# There is no sphinx.main in Sphinx 2
sed -i 's/sphinx\.main/sphinx.cmd.build.main/g' $(grep -r 'sphinx\.main' -l)
sed -i 's/import sphinx/import sphinx.cmd.build/g' $(grep -r 'import sphinx' -l)

# Trick Python 2 to build docs by Python 3
sed -i 's/$PYTHON2 -c '"'"'import sphinx/python3 -c '"'"'import sphinx/' configure configure.ac
sed -i 's/PYTHONPATH=..:$$PYTHONPATH $(OSX_SIP_HACK_ENV) $(PYTHON2)/PYTHONPATH=..:$$PYTHONPATH $(OSX_SIP_HACK_ENV) python3/' python/Makefile.am python/Makefile.in

%build
%if 0%{?with_py3}
export PYTHON3_LIB=%{python3_sitelib}
%endif
export RUBY_LIB=%{ruby_vendorlibdir}
export RUBY_LIB_ARCH=%{ruby_vendorarchdir}

%configure \
%if 0%{?with_py3}
       %{?with_py3:--with-python3} \
%endif
       --with-ruby --with-tcl

%{make_build}

%install
%{make_install}

# Remove the dev docs, we pick them up below
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%check
#make check

%files
%license COPYING
%doc AUTHORS NEWS README

%if 0%{?with_py3}
%files -n python3-xapian
%{python3_sitelib}/xapian/
%endif

%files ruby
%{ruby_vendorarchdir}/_xapian.so
%{ruby_vendorlibdir}/xapian.rb

%files -n tcl-xapian
%{_libdir}/tcl%{tcl_version}/xapian%{version}/

%changelog
* Sun Feb 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.4.14-1
- Update to 1.4.14

* Mon Jun 18 2007 Marco Pesenti Gritti <mpg@redhat.com> 1.0.1-1
- Initial build

